/***********************************************************************
 *                copyright 2001, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/
#include <stdio.h>
#include <string.h>
#ifdef USE_SYS_MALLOC
#include <sys/malloc.h>
#else
#include <malloc.h>
#endif

#ifdef HPUX
#define LAUNCH launch
#else
#define LAUNCH launch_
#endif

LAUNCH(cmd,lcmd) /* use real system() instead of brain-damaged f77 version */
char *cmd; 
long lcmd;
{
	char *buf;
	int ret;

	if ((buf=malloc((unsigned)lcmd+1))) {
fprintf(stderr, ">%s<\n", strncpy(buf,cmd,(int)lcmd));
		ret = system(strncpy(buf,cmd,(int)lcmd));
		free(buf);
fprintf(stderr, "ret = %d\n", ret);
		return ret;
	}

	fprintf(stderr,"launch: out of memory.\n");

	return -1;

}
